===============
Counterfactuals
===============

Comparison of counterfactual explanations
=========================================

The following example show a few ways of computing counterfactual explanations.

.. literalinclude:: code/counterfactuals.py

.. figure:: fig/counterfactuals.png